@@ -1,9 +1,7 @@
 use strict;
 use warnings;
 package String::Formatter;
-our $VERSION = '0.093221';
-
-
+our $VERSION = '0.100680';
 # ABSTRACT: build sprintf-like functions of your own
 
 
@@ -123,7 +121,7 @@ sub hunk_simply {
   my @to_fmt;
   my $pos = 0;
 
-  while ($string =~ m{\G(.*?)$regex}g) {
+  while ($string =~ m{\G(.*?)$regex}gs) {
     push @to_fmt, $1, {
       orig      => $2,
       alignment => $3,
@@ -274,7 +272,7 @@ String::Formatter - build sprintf-like functions of your own
 
 =head1 VERSION
 
-version 0.093221
+version 0.100680
 
 =head1 WARNING
 
@@ -517,27 +515,27 @@ hashref can be accessed later with the C<codes> method.
 The other four arguments change how the formatting occurs.  Formatting happens
 in five phases:
 
-=over
+=over 4
 
-=item 1.
+=item 1
 
 format_hunker - format string is broken down into fixed and %-code hunks
 
-=item 2.
+=item 2
 
 input_processor - the other inputs are validated and processed
 
-=item 3.
+=item 3
 
 string_replacer - replacement strings are generated by using conversions
 
-=item 4.
+=item 4
 
 hunk_formatter - replacement strings in hunks are formatted
 
-=item 5.
+=item 5
 
-all hunks, now strings, are recombined; this phase is just C<<< join >>>
+all hunks, now strings, are recombined; this phase is just C<join>
 
 =back
 
@@ -559,7 +557,7 @@ String::Formatter.  Very little of the original code remains.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2009 by Ricardo Signes <rjbs@cpan.org>.
+This software is Copyright (c) 2010 by Ricardo Signes <rjbs@cpan.org>.
 
 This is free software, licensed under:
 
